<?php

namespace Drupal\visitors\Controller\Report;

use Drupal\Core\Datetime\DateFormatterInterface;
use Drupal\Core\Form\FormBuilderInterface;
use Drupal\Core\StringTranslation\TranslationInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Host Report controller.
 */
final class HostController extends ReportController {
  /**
   * The date service.
   *
   * @var \Drupal\Core\Datetime\DateFormatterInterface
   */
  protected $date;

  /**
   * The form builder service.
   *
   * @var \Drupal\Core\Form\FormBuilderInterface
   */
  protected $formBuilder;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container): HostController {
    return new self(
      $container->get('date.formatter'),
      $container->get('form_builder'),
      $container->get('string_translation')
    );
  }

  /**
   * Constructs a Hosts object.
   *
   * @param \Drupal\Core\Datetime\DateFormatterInterface $date_formatter
   *   The date service.
   * @param \Drupal\Core\Form\FormBuilderInterface $form_builder
   *   The form builder service.
   * @param \Drupal\Core\StringTranslation\TranslationInterface $string_translation
   *   The string translation service.
   */
  public function __construct(
    DateFormatterInterface $date_formatter,
    FormBuilderInterface $form_builder,
    TranslationInterface $string_translation,
  ) {

    $this->date        = $date_formatter;
    $this->formBuilder = $form_builder;
    $this->setStringTranslation($string_translation);

  }

  /**
   * Returns a hosts page.
   *
   * @return array
   *   A render array representing the hosts page content.
   */
  public function top(): array {
    $form = $this->formBuilder->getForm('Drupal\visitors\Form\DateFilter');
    $blocks['path'] = [
      '#view_id'      => 'visitors_top_visits',
      '#view_display' => 'host',
    ];

    return [
      'visitors_date_filter_form' => $form,
      'main' => [
        '#type' => 'container',
        '#attributes' => [
          'class' => ['visitors-main'],
        ],
        '1' => [
          $this->renderBlocks($blocks),
        ],
      ],
    ];
  }

  /**
   * Returns a hosts page.
   *
   * @return array
   *   A render array representing the hosts page content.
   */
  public function recent($host): array {
    $form = $this->formBuilder->getForm('Drupal\visitors\Form\DateFilter');
    $blocks['path'] = [
      '#view_id'      => 'visitors_recent_visits',
      '#view_display' => 'host',
    ];

    return [
      'visitors_date_filter_form' => $form,
      'main' => [
        '#type' => 'container',
        '#attributes' => [
          'class' => ['visitors-main'],
        ],
        '1' => [
          $this->renderBlocks($blocks, NULL, $host),
        ],
      ],
    ];
  }

  /**
   * Returns a title for the page.
   */
  public function getTitle(string $host) {
    $title = $this->stringTranslation
      ->translate('Visits from @host', ['@host' => $host]);

    return $title;
  }

}
