<?php

namespace Drupal\visitors\Controller\Report;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Datetime\DateFormatterInterface;
use Drupal\Core\Form\FormBuilderInterface;
use Drupal\Core\StringTranslation\TranslationInterface;
use Drupal\visitors\VisitorsReportInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Referer Report controller.
 */
final class PerformanceController extends ControllerBase {

  /**
   * The date service.
   *
   * @var \Drupal\Core\Datetime\DateFormatterInterface
   */
  protected $date;

  /**
   * The form builder service.
   *
   * @var \Drupal\Core\Form\FormBuilderInterface
   */
  protected $formBuilder;

  /**
   * The report service.
   *
   * @var \Drupal\visitors\VisitorsReportInterface
   */
  protected $report;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container): PerformanceController {
    return new self(
      $container->get('date.formatter'),
      $container->get('form_builder'),
      $container->get('visitors.report'),
      $container->get('string_translation')
    );
  }

  /**
   * Constructs a Hours object.
   *
   * @param \Drupal\Core\Datetime\DateFormatterInterface $date_formatter
   *   The date service.
   * @param \Drupal\Core\Form\FormBuilderInterface $form_builder
   *   The form builder service.
   * @param \Drupal\visitors\VisitorsReportInterface $report_service
   *   The report service.
   * @param \Drupal\Core\StringTranslation\TranslationInterface $string_translation
   *   The string translation service.
   */
  public function __construct(
    DateFormatterInterface $date_formatter,
    FormBuilderInterface $form_builder,
    VisitorsReportInterface $report_service,
    TranslationInterface $string_translation,
  ) {

    $this->date        = $date_formatter;
    $this->formBuilder = $form_builder;
    $this->report      = $report_service;
    $this->setStringTranslation($string_translation);

  }

  /**
   * Display the performance report.
   */
  public function display() {
    $form = $this->formBuilder->getForm('Drupal\visitors\Form\DateFilter');

    $results = $this->report->performance();
    $return = [
      'visitors_date_filter_form' => $form,
      'visitors_performance' => ['#markup' => $this->t('No performance data available.')],

    ];
    if (count($results['day']) > 0) {
      $return['visitors_performance'] = [
        '#theme'  => 'visitors_jqplot_stacked',
        '#x'      => $results['day'],
        '#network' => $results['network'],
        '#server'  => $results['server'],
        '#transfer' => $results['transfer'],
        '#dom_processing' => $results['dom_processing'],
        '#dom_complete' => $results['dom_complete'],
        '#on_load' => $results['on_load'],
        '#width'  => $this->report->width(),
        '#height' => $this->report->height(),
      ];
    }

    return $return;
  }

}
