<?php

namespace Drupal\visitors\Controller\Report;

use Drupal\Core\Datetime\DateFormatterInterface;
use Drupal\Core\Form\FormBuilderInterface;
use Drupal\Core\StringTranslation\TranslationInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Recent Hits Report controller.
 */
final class RecentHits extends ReportController {
  /**
   * The date service.
   *
   * @var \Drupal\Core\Datetime\DateFormatterInterface
   */
  protected $date;

  /**
   * The form builder service.
   *
   * @var \Drupal\Core\Form\FormBuilderInterface
   */
  protected $formBuilder;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container): RecentHits {
    return new self(
      $container->get('date.formatter'),
      $container->get('form_builder'),
      $container->get('string_translation')
    );
  }

  /**
   * Constructs a RecentHits object.
   *
   * @param \Drupal\Core\Datetime\DateFormatterInterface $date_formatter
   *   The date service.
   * @param \Drupal\Core\Form\FormBuilderInterface $form_builder
   *   The form builder service.
   * @param \Drupal\Core\StringTranslation\TranslationInterface $string_translation
   *   The string translation service.
   */
  public function __construct(
    DateFormatterInterface $date_formatter,
    FormBuilderInterface $form_builder,
    TranslationInterface $string_translation,
  ) {

    $this->date        = $date_formatter;
    $this->formBuilder = $form_builder;
    $this->setStringTranslation($string_translation);

  }

  /**
   * Returns a recent hits page.
   *
   * @return array
   *   A render array representing the recent hits page content.
   */
  public function display(): array {
    $form = $this->formBuilder->getForm('Drupal\visitors\Form\DateFilter');
    $blocks['path'] = [
      '#view_id'      => 'visitors_recent_visits',
      '#view_display' => 'recent',
    ];

    return [
      'visitors_date_filter_form' => $form,
      'main' => [
        '#type' => 'container',
        '#attributes' => [
          'class' => ['visitors-main'],
        ],
        '1' => [
          $this->renderBlocks($blocks),
        ],
      ],
    ];
  }

}
