<?php

namespace Drupal\visitors\Plugin\views\field;

use Drupal\views\Plugin\views\field\FieldPluginBase;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Field handler to display the browser version of the visitors.
 *
 * @ingroup views_field_handlers
 *
 * @ViewsField("visitors_browser_version")
 */
final class VisitorsBrowserVersion extends FieldPluginBase {

  /**
   * The database driver type.
   *
   * @var string
   */
  protected $driver;

  /**
   * Browser version field.
   *
   * @param array $configuration
   *   The plugin configuration.
   * @param string $plugin_id
   *   The plugin ID.
   * @param mixed $plugin_definition
   *   The plugin definition.
   * @param string $driver
   *   The database driver type.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, string $driver) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->driver = $driver;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new self(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('database')->driver()
    );
  }

  /**
   * {@inheritdoc}
   */
  public function query() {

    $this->ensureMyTable();
    // Add the field.
    $params = $this->options['group_type'] != 'group' ? ['function' => $this->options['group_type']] : [];

    switch ($this->driver) {
      case 'sqlite':
        $formula = "{$this->tableAlias}.config_browser_name || ' ' || {$this->tableAlias}.{$this->realField}";
        break;

      case 'mysql':
      default:
        $formula = "CONCAT_WS(' ', {$this->tableAlias}.config_browser_name, {$this->tableAlias}.{$this->realField})";
        break;
    }

    $this->field_alias = $this->query->addField(NULL, $formula, "{$this->tableAlias}_{$this->realField}", $params);

    $this->addAdditionalFields();
  }

}
