<?php

namespace Drupal\visitors;

/**
 * Visitors report data.
 */
interface VisitorsReportInterface {

  /**
   * The number of hits for each day of the month.
   */
  const REFERER_TYPE_INTERNAL_PAGES = 0;

  /**
   * The number of hits for each day of the month.
   */
  const REFERER_TYPE_EXTERNAL_PAGES = 1;

  /**
   * Get the number of hits for each day of the month.
   *
   * @param array $header
   *   Table header configuration.
   *
   * @return array
   *   The number of hits for each day of the month.
   */
  public function daysOfMonth(array $header = NULL);

  /**
   * Get the number of hits for each day of the week.
   *
   * @return array
   *   The number of hits for each day of the week.
   */
  public function daysOfWeek();

  /**
   * Get the number of hits for each hour of the day.
   *
   * @param mixed $header
   *   Table header configuration.
   *
   * @return array
   *   The number of hits for each hour of the day.
   */
  public function hours($header = NULL);

  /**
   * Get the number of hits for each month of the year.
   *
   * @param array $header
   *   Table header configuration.
   *
   * @return array
   *   The number of hits for each month of the year.
   */
  public function monthly(array $header = NULL);

  /**
   * Get the number of hits for each referer.
   *
   * @param array $header
   *   Table header configuration.
   *
   * @return array
   *   The number of hits for each referer.
   */
  public function referer(array $header);

  /**
   * Get the number of hits for each user agent.
   *
   * @param array $header
   *   Table header configuration.
   *
   * @return array
   *   The number of hits for each user agent.
   */
  public function activity(array $header);

  /**
   * Returns chart width.
   */
  public function width();

  /**
   * Returns chart height.
   */
  public function height();

  /**
   * Returns a translated days of week array.
   *
   * @return array
   *   An array of translated days.
   */
  public function getTranslatedDays();

  /**
   * Details about the visit.
   *
   * @param int $hit_id
   *   The hit id.
   *
   * @return array
   *   The details about the visit.
   */
  public function hitDetails($hit_id);

  /**
   * Visits related to the node.
   *
   * @param array $header
   *   Table header configuration.
   * @param int $nid
   *   The node id.
   *
   * @return array
   *   The visits related to a node.
   */
  public function node(array $header, int $nid);

  /**
   * Performance report.
   *
   * @return array
   *   The performance report.
   */
  public function performance(): array;

}
