<?php

namespace Drupal\Tests\visitors\Unit\Controller\Report;

use Drupal\Core\Datetime\DateFormatterInterface;
use Drupal\Core\Form\FormBuilderInterface;
use Drupal\Core\Form\FormInterface;
use Drupal\Tests\UnitTestCase;
use Drupal\visitors\Controller\Report\HostController;
use Symfony\Component\DependencyInjection\ContainerBuilder;

/**
 * Unit tests for the Host controller.
 *
 * @group visitors
 */
class HostControllerTest extends UnitTestCase {

  /**
   * The mocked date formatter service.
   *
   * @var \Drupal\Core\Datetime\DateFormatterInterface|\PHPUnit\Framework\MockObject\MockObject
   */
  protected $dateFormatter;

  /**
   * The mocked form builder service.
   *
   * @var \Drupal\Core\Form\FormBuilderInterface|\PHPUnit\Framework\MockObject\MockObject
   */
  protected $formBuilder;

  /**
   * The Hosts controller under test.
   *
   * @var \Drupal\visitors\Controller\Report\HostController
   */
  protected $controller;

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();
    require_once __DIR__ . '/../../../../fixtures/views_embed_view.php';

    $container = new ContainerBuilder();

    $this->dateFormatter = $this->createMock(DateFormatterInterface::class);
    $container->set('date.formatter', $this->dateFormatter);

    $this->formBuilder = $this->createMock(FormBuilderInterface::class);
    $container->set('form_builder', $this->formBuilder);

    $string_translation = $this->getStringTranslationStub();
    $container->set('string_translation', $string_translation);

    $this->controller = HostController::create($container);
  }

  /**
   * Tests the top() method of the Hosts controller.
   */
  public function testTop(): void {
    // Mock the necessary objects and their methods.
    $form = $this->createMock(FormInterface::class);
    $this->formBuilder->expects($this->once())
      ->method('getForm')
      ->with('Drupal\visitors\Form\DateFilter')
      ->willReturn($form);

    // Execute the display() method.
    $renderArray = $this->controller->top();

    // Assertions for the returned render array.
    $this->assertArrayHasKey('visitors_date_filter_form', $renderArray);
    $this->assertArrayHasKey('main', $renderArray);

  }

  /**
   * Tests the recent() method.
   */
  public function testRecent(): void {

    $form = $this->createMock(FormInterface::class);

    $this->formBuilder->expects($this->once())
      ->method('getForm')
      ->with('Drupal\visitors\Form\DateFilter')
      ->willReturn($form);

    $renderArray = $this->controller->recent('10.10.10.10');

    $this->assertArrayHasKey('visitors_date_filter_form', $renderArray);
    $this->assertArrayHasKey('main', $renderArray);
  }

  /**
   * Tests the getTitle() method.
   */
  public function testTitle(): void {
    $title = $this->controller->getTitle('10.10.10.10');
    $this->assertEquals('Visits from 10.10.10.10', $title);
  }

}
